[Zodb-checkins] SVN: ZODB/trunk/src/ZODB/tests/TransactionalUndoStorage.py Renamed getSerial to getTid.

Jim Fulton jim at zope.com
Thu Apr 26 19:19:57 EDT 2007


Log message for revision 74834:
  Renamed getSerial to getTid.
  

Changed:
  U   ZODB/trunk/src/ZODB/tests/TransactionalUndoStorage.py

-=-
Modified: ZODB/trunk/src/ZODB/tests/TransactionalUndoStorage.py
===================================================================
--- ZODB/trunk/src/ZODB/tests/TransactionalUndoStorage.py	2007-04-26 23:19:52 UTC (rev 74833)
+++ ZODB/trunk/src/ZODB/tests/TransactionalUndoStorage.py	2007-04-26 23:19:56 UTC (rev 74834)
@@ -143,7 +143,7 @@
         eq(zodb_unpickle(data), MinPO(23))
         self._iterate()
 
-    def checkCreationUndoneGetSerial(self):
+    def checkCreationUndoneGetTid(self):
         # create an object
         oid = self._storage.new_oid()
         self._dostore(oid, data=MinPO(23))
@@ -156,9 +156,9 @@
         self._storage.undo(tid, t)
         self._storage.tpc_vote(t)
         self._storage.tpc_finish(t)
         # Check that calling getSerial on an uncreated object raises a KeyError
         # The current version of FileStorage fails this test
-        self.assertRaises(KeyError, self._storage.getSerial, oid)
+        self.assertRaises(KeyError, self._storage.getTid, oid)
 
     def checkUndoCreationBranch1(self):
         eq = self.assertEqual
@@ -156,9 +156,9 @@
         self._storage.tpc_vote(t)
         self._storage.tpc_finish(t)
-        # Check that calling getSerial on an uncreated object raises a KeyError
+        # Check that calling getTid on an uncreated object raises a KeyError
         # The current version of FileStorage fails this test



More information about the Zodb-checkins mailing list